IF OBJECT_ID('[BuildTriggerExecutions_Extended]') IS NOT NULL DROP VIEW [BuildTriggerExecutions_Extended]
GO

CREATE VIEW [BuildTriggerExecutions_Extended] AS

	SELECT BTE.[Execution_Id]
		  ,A.[Application_Id]
		  ,BTE.[Plan_Name]
		  ,[ExecutionStart_Date] = E.[Start_Date]
		  ,[ExecutionEnded_Date] = E.[End_Date]
		  ,E.[ExecutionRunState_Code]
		  ,E.[ExecutionStatus_Code]
		  ,[ExecutionStatus_Name] =
		   CASE
				WHEN E.[ExecutionRunState_Code] = 'P' THEN 'Pending'
				WHEN E.[ExecutionRunState_Code] = 'X' AND E.[CanceledOn_Date] IS NULL THEN 'Executing'
				WHEN E.[ExecutionRunState_Code] = 'X' AND E.[CanceledOn_Date] IS NOT NULL THEN 'Canceled'
				WHEN E.[ExecutionStatus_Code] = 'E' THEN 'Failed'
				ELSE 'Succeeded'
		   END
		  ,E.[CreatedBy_User_Name]
		  ,E.[CreatedOn_Date]
		  ,E.[CanceledBy_User_Name]
		  ,E.[CanceledOn_Date]
		  ,A.[Application_Name]
		  ,[WarningLogEntry_Indicator] = CASE WHEN E.[ExecutionStatus_Code] = 'W' THEN 'Y' ELSE 'N' END
		  ,A.[ApplicationGroup_Id]
		  ,BTE.[RepositoryMonitor_Id]
		  ,RM.[RepositoryMonitor_Name]
		  ,BTE.[Webhook_Id]
		  ,W.[Webhook_Name]
		  ,RM.[ReleaseNumberFilter_Text]

	  FROM [BuildTriggerExecutions] BTE
	       INNER JOIN [Executions] E
		          ON E.[Execution_Id] = BTE.[Execution_Id]
		    LEFT JOIN [Applications] A
				  ON A.[Application_Id] = BTE.[Application_Id]
		    LEFT JOIN [RepositoryMonitors] RM
		           ON RM.[RepositoryMonitor_Id] = BTE.[RepositoryMonitor_Id]
		    LEFT JOIN [Webhooks] W
		           ON W.[Webhook_Id] = BTE.[Webhook_Id]

GO
