EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Pipelines_RenamePipeline',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Renames a pipeline across active (or optionally, inactive) builds and releases.'
GO

IF OBJECT_ID('[Pipelines_RenamePipeline]') IS NOT NULL DROP PROCEDURE [Pipelines_RenamePipeline]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Pipelines_RenamePipeline]
(
	@Old_Pipeline_Name VARCHAR(255),
	@New_Pipeline_Name VARCHAR(255),
	@LimitTo_Application_Id INT,
	@Include_Active YNINDICATOR,
	@Include_Inactive YNINDICATOR
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	UPDATE [Releases]
	   SET [Pipeline_Name] = @New_Pipeline_Name
	 WHERE [Pipeline_Name] = @Old_Pipeline_Name
	   AND (@LimitTo_Application_Id IS NULL OR [Application_Id] = @LimitTo_Application_Id)
	   AND (   (@Include_Active = 'Y' AND [ReleaseStatus_Name] = 'Active')
	        OR (@Include_Inactive = 'Y' AND [ReleaseStatus_Name] <> 'Active'))

	UPDATE [Builds]
	   SET [Pipeline_Name] = @New_Pipeline_Name
	 WHERE [Pipeline_Name] = @Old_Pipeline_Name
	   AND (@LimitTo_Application_Id IS NULL OR [Application_Id] = @LimitTo_Application_Id)
	   AND (   (@Include_Active = 'Y' AND [BuildStatus_Name] = 'Active')
	        OR (@Include_Inactive = 'Y' AND [BuildStatus_Name] <> 'Active'))


	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [Pipelines_RenamePipeline] TO [BuildMasterUser_Role]
